@@ -9,7 +9,8 @@ def configure_logging(file_name: str):
     consoleHandler.setLevel(logging.DEBUG)
 
     logger.addHandler(consoleHandler)
+    fmt = '%(levelname)s file: %(name)s  func: %(funcName)20s() line: %(lineno)d  -> %(message)s'
 
-    coloredlogs.install(level='DEBUG', logger=logger, fmt='%(levelname)s file: %(name)s line: %(lineno)d  -> %(message)s')
+    coloredlogs.install(level='DEBUG', logger=logger, fmt=fmt, )
 
     return logger
